package com.muyu.common.domain;

import com.baomidou.mybatisplus.annotation.TableField;
import com.baomidou.mybatisplus.annotation.TableName;
import lombok.AllArgsConstructor;
import lombok.Builder;
import lombok.Data;
import lombok.NoArgsConstructor;

import java.util.List;
import java.util.function.Supplier;

/**
 * @Author：张腾
 * @Package：com.muyu.common.domain 配置类
 * @Project：cloud-integration
 * @name：Connection
 * @Date：2024/8/21 1:00
 */
@Data
@Builder
@NoArgsConstructor
@AllArgsConstructor
@TableName("connect")
public class Connect {

    /**
     * id
     */
    private Integer id;

    /**
     * 接入源名称
     */
    private String accSourName;

    /**
     * 数据来源系统名称
     */
    private String dataSourSystemName;

    /**
     * 表名
     */
    private String tableName;

    /**
     * ip地址
     */
    private String ipAddress;

    /**
     * 端口号地址
     */
    private String port;

    /**
     * 数据库名称
     */
    private String databaseName;

    /**
     * 数据接入类型
     */
    @TableField("data_acc_type")
    private String dataAccType;

    /**
     * 用户名
     */
    private String userName;

    /**
     * 密码
     */
    private String password;

    /**
     * 是否初始化
     */
    private String initialization;

    /**
     * 备注
     */
    private String notes;


    /**
     * 数据连接参数
     */
    private String dataConnParam;

    /**
     * 初始连接数量
     */
    private Integer initSize;
    /**
     * 最大连接数量
     */
    private Integer maxNumConn;
    /**
     * 最大等待时间
     */
    private Integer maxWaitTime;
    /**
     * 最大等待次数
     */
    private Integer maxWaitTimes;

    /**
     * 客户最近5条支付单
     */
    @TableField(exist = false)
    private List<Connect> connectList;

    public static Connect connectBuild(Connect connect1, Supplier<List<Connect>> function) {
        return Connect.builder()
                .id(connect1.getId())
                .accSourName(connect1.getAccSourName())
                .dataSourSystemName(connect1.getDataSourSystemName())
                .tableName(connect1.getTableName())
                .ipAddress(connect1.getIpAddress())
                .port(connect1.getPort())
                .databaseName(connect1.getDatabaseName())
                .dataAccType(connect1.getDataAccType())
                .userName(connect1.getUserName())
                .password(connect1.getPassword())
                .initialization(connect1.getInitialization())
                .notes(connect1.getNotes())
                .dataConnParam(connect1.getDataConnParam())
                .initSize(connect1.getInitSize())
                .maxNumConn(connect1.getMaxNumConn())
                .maxWaitTime(connect1.getMaxWaitTime())
                .maxWaitTimes(connect1.getMaxWaitTimes())
                .connectList(function.get())
                .build();
    }


}
