package com.muyu.common.domain;

import com.baomidou.mybatisplus.annotation.IdType;
import com.baomidou.mybatisplus.annotation.TableId;
import com.baomidou.mybatisplus.annotation.TableName;
import com.muyu.common.core.annotation.Excel;
import com.muyu.common.core.web.domain.BaseEntity;
import io.swagger.v3.oas.annotations.tags.Tag;
import lombok.AllArgsConstructor;
import lombok.Data;
import lombok.EqualsAndHashCode;
import lombok.NoArgsConstructor;
import lombok.experimental.SuperBuilder;

import java.util.Date;
import java.util.function.Supplier;


/**
 * @Author：李庆帅
 * @Package：com.muyu.etl.domain.resp
 * @Project：cloud-etl-property
 * @name：EtlDataScore  数据来源信息实体类
 * @Date：2024/8/21 11:02
 */
@Data
@SuperBuilder
@AllArgsConstructor
@NoArgsConstructor
@Tag(name = "数据来源信息")
@EqualsAndHashCode(callSuper = true)
@TableName(value = "etl_data_score", autoResultMap = true)
public class EtlDataScore extends BaseEntity {


    /**
     *  id
     *  */
    @TableId(type = IdType.AUTO)
    private Long id ;
    /**
     * 数据来源名称
     * */
    @Excel(name = "数据来源名称")
    private String name ;

//    /** 数据来源系统名称 */
//    @Excel(name = "数据来源系统名称")
//    private String dataSourcesSystemName;

    /**
     * 数据来源类型
     * */
    @Excel(name = "数据来源类型")
    private String type ;
    /**
     *  数据来源地址
     *  */
    @Excel(name = "数据来源地址")
    private String host ;

    /**
     *  来源地址端口号
     *  */
    @Excel(name = "来源地址端口号")
    private String port ;

    /**
     * 存放数据库名称
     * */
    @Excel(name = "存放数据库名称")
    private String databaseName ;

    /**
     * 数据库登录名
     *
     * */
    @Excel(name = "数据库登录名")
    private String userName ;

    /**
     * 数据库登录密码
     * */
    @Excel(name = "数据库登录密码")
    private String password ;
    /**
     *  数据库字符集编码
     *  */
    @Excel(name = "数据库字符集编码")
    private String dbEncoding ;
    /**
     *  参数
     *  */
    @Excel(name = "参数")
    private String param ;

    /**
     * 状态 1初始化 2 不初始化
     * */
//    @Excel(name = "状态")
    private String status ;

    /**
     *  初始连接数量
     *  */
    @Excel(name = "初始连接数量")
    private Integer initCount;

    /**
     * 最大连接数量
     * */
    @Excel(name = "最大连接数量")
    private Integer maxCount;

    /**
     *  最大等待时间
     *  */
//    @JsonFormat(pattern = "yyyy-MM-dd HH:mm:ss")
//    @Schema(description = "最大等待时间",defaultValue = "2024-7-31 14:30:29",type = "Date")
            //3000ms
    @Excel(name = "最大等待时间")
    private Integer maxTime;

    /**
     * 最大等待次数
     * */
    @Excel(name = "最大等待次数")
    private Integer maxFrequency;

    /**
     *  驱动 com.mysql.cj.jdbc.Driver
     *  */
    @Excel(name = "驱动",defaultValue = "com.mysql.cj.jdbc.Driver")
    private String driverName;

    /**
     * 备注
     */
    @Excel(name = "备注")
    private String remark;



//    /**
//     * 添加
//     * @param req
//     * @return
//     */
//    public static EtlDataScore addBuild(EtlDataScoreAddReq req){
//        return EtlDataScore.builder()
//                .type(req.getType())
//                .name(req.getName())
//                .host(req.getHost())
//                .port(req.getPort())
//                .databaseName(req.getDatabaseName())
//                .userName(req.getUserName())
//                .password(req.getPassword())
//                .param(req.getParam())
//                .status(req.getStatus())
//                .initCount(req.getInitCount())
//                .maxCount(req.getMaxCount())
//                .maxTime(req.getMaxTime())
//                .maxFrequency(req.getMaxFrequency())
//                .driverName("com.mysql.cj.jdbc.Driver")
//                .build();
//    }
//
//    /**
//     * 修改
//     * @param req
//     * @return
//     */
//    public static EtlDataScore updBuild(EtlDataScoreUpdReq req, Supplier<Long> idSupplier){
//        return EtlDataScore.builder()
//                .id(idSupplier.get())
//                .type(req.getType())
//                .name(req.getName())
//                .host(req.getHost())
//                .port(req.getPort())
//                .databaseName(req.getDatabaseName())
//                .userName(req.getUserName())
//                .password(req.getPassword())
//                .param(req.getParam())
//                .status(req.getStatus())
//                .initCount(req.getInitCount())
//                .maxCount(req.getMaxCount())
//                .maxTime(req.getMaxTime())
//                .maxFrequency(req.getMaxFrequency())
//                .driverName(req.getDriverName())
//                .build();
//    }
//
//    /**
//     * 获取数据库连接
//     * @return
//     */
//    public String getUrl(){
//        StringBuilder urlSb = new StringBuilder(BaseConfig.MYSQLJDBCPRO);
//        urlSb.append(this.host);//拼接ip
//        urlSb.append(":");
//        urlSb.append(this.port); //拼接端口
//        urlSb.append("/");
//        urlSb.append(this.databaseName);//拼接数据库
//        urlSb.append("?");
//        urlSb.append(this.param);//useUnicode=true&characterEncoding=utf8&zeroDateTimeBehavior=convertToNull&useSSL=true&serverTimezone=GMT%2B8
//        return urlSb.toString();
//    }


}
