package com.muyu.server.controller;

import com.muyu.common.core.domain.Result;
import com.muyu.common.domain.*;
import com.muyu.common.security.annotation.RequiresPermissions;
import com.muyu.common.system.domain.SysDept;
import com.muyu.server.service.AssetAuthorizationService;
import com.muyu.server.service.DataRunNameService;
import io.swagger.v3.oas.annotations.Operation;
import io.swagger.v3.oas.annotations.tags.Tag;
import lombok.AllArgsConstructor;
import org.springframework.web.bind.annotation.*;

import java.util.List;

import static com.muyu.common.core.domain.Result.success;

/**
 * @Author：yang
 * @Package：com.muyu.server.controller 级联
 * @Project：cloud-property
 * @name：DataRunNameController
 * @Date：2024/8/27 22:09
 */
@RestController
@RequestMapping("/dataRunName")
@Tag(name = "抽取数据名，数据表名",description = "级联")
@AllArgsConstructor
public class DataRunNameController {

    private DataRunNameService dataRunNameService;
    private final AssetAuthorizationService assetAuthorizationService;

    /**
     * 添加 数据库名，表名，结构
     */
    @PostMapping("/addDataTableName")
    @Operation(summary = "添加数据库名，表名，结构",description = "获取数据进行添加")
    public Result<String> addDataTableName(@RequestBody Connect connect){
        String s = dataRunNameService.addDataTableName(connect);
        return success(s,"同步成功");
    }

    /**
     *  连接数据库获取当前所有的数据库名称
     * @return 所有数据库以及所有表的结果集
     */
    @PostMapping("/extractDataName")
    @Operation(summary = "获取数据库名",description = "返回所有数据库以及所有表的结果集")
    public Result<List<DataName>> getDatabase(){

        return success(dataRunNameService.getDatabasesName());
    }

    /**
     *  连接数据库获取当前所有的数据库名称和所有字段
     * @return 所有数据库以及所有表的结果集
     */
    @PostMapping("/extractDataTableName")
    @Operation(summary = "获取数据库名",description = "返回所有数据库以及所有表的结果集")
    public Result<List<DataName>> getDataBaseTableName(){
        return success(dataRunNameService.getDataBaseTableName());
    }

    /**
     *  点击获取字段  映射  和类型信息
     * @return 返回结果集
     */
    @PostMapping("/tableStructureShow")
    @Operation(summary = "获取数据库名",description = "返回所有数据库以及所有表的结果集")
    public Result<List<TableFie>> tableStructureShow(@RequestBody TableNames tableNames){
        return success(dataRunNameService.tableStructureShow(tableNames));
    }

    /**
     * 资产展示
     *  连接数据库获取当前所有的数据库名称和所有字段
     * @return 所有数据库以及所有表的结果集
     */
    @PostMapping("/extractDataTableNameShow")
    @Operation(summary = "获取数据",description = "返回所有数据库以及所有表的结果集到资产展示")
    public Result<List<DataName>> extractDataTableNameShow(){

        return success(dataRunNameService.extractDataTableNameShow());
    }

    /**
     * 数据类型转换
     * @par 数据类型转换ID
     * @return 返回结果
     */
    @PostMapping("/findTableValue")
    @Operation(summary = "获取数据库名",description = "返回所有数据库以及所有表的结果集")
    public Result<List<DataValue>> findTableValue(
            @RequestParam(name = "dataId") String dataId,
            @RequestParam(name = "tableName") String tableName
    ){

        return success(dataRunNameService.findTableValue(dataId,tableName));
    }

    /**
     * 数据类型转换
     * @par 数据类型转换ID
     * @return 返回结果
     */
    @PostMapping("/selectBasicList")
    @Operation(summary = "获取数据库名",description = "返回所有数据库以及所有表的结果集")
    public Result<List<DataValue>> selectBasicList(){

        return success(dataRunNameService.selectBasicList());
    }

    /**
     * 获取表中的数据值前台调用 闪闪
     * @param basicId 响应参数
     * @param tableName 响应参数
     * @return 返回结果
     */
    @PostMapping("/findTableValueList")
    @Operation(summary = "获取表中的数据值提供给任务模块调用",
            description = "获取表中的数据值提供给任务模块调用")
    public Result findTableValueByTableName(@RequestParam("basicId") Long basicId,
                                            @RequestParam("dataId") String dataId,
                                            @RequestParam("tableName") String tableName){


        List<DataValue> list = dataRunNameService.findTableValueByTableName(basicId,dataId,tableName);
        return success(list);
    }



    /**
     * 添加用户权限的信息
     * @param req 相应参数
     * @return 返回结果
     */
    @PostMapping("/addUserAssetAuthorization")
    @Operation(summary = "添加用户权限的信息",
            description = "添加用户权限的信息")
    public Result addUserAssetAuthorization(@RequestBody AssetAuthorization req){
        AssetAuthorization authorization = new AssetAuthorization();
        authorization.setUserId(req.getUserId());
        authorization.setTableId(req.getTableId());
        authorization.setBasicId(req.getBasicId());
        boolean save = dataRunNameService.addUserAssetAuthorization(authorization);
        return save?Result.success():Result.error();
    }

    /**
     * 删除用户权限的信息
     * @param req 响应参数
     * @return  返回结果
     */
    @PostMapping("/delUserAssetAuthorization")
    @Operation(summary = "删除用户权限的信息",
            description = "删除用户权限的信息")
    public Result delUserAssetAuthorization(@RequestBody AssetAuthorization req){
        Long i = assetAuthorizationService.delUserAssetAccredit(req);
        return i>0?Result.success():Result.error();
    };

    /**
     * 添加部门权限的信息
     * @param req 响应参数
     * @return 返回结果
     */
    @PostMapping("/addDeptAssetAuthorization")
    @Operation(summary = "添加部门权限的信息",
            description = "添加部门权限的信息")
    public Result addDeptAssetAuthorization(@RequestBody AssetAuthorization req){
        AssetAuthorization authorization = new AssetAuthorization();
        authorization.setDeptId(req.getDeptId());
        authorization.setTableId(req.getTableId());
        authorization.setBasicId(req.getBasicId());
        boolean save = dataRunNameService.addDeptAssetAuthorization(authorization);
        return save?Result.success():Result.error();
    }

    /**
     * 删除部门权限的信息
     * @param req 响应参数
     * @return  返回结果
     */
    @PostMapping("/delDeptAssetAuthorization")
    @Operation(summary = "删除部门权限的信息",
            description = "删除部门权限的信息")
    public Result delDeptAssetAuthorization(@RequestBody AssetAuthorization req){
        Long i = assetAuthorizationService.delDeptAssetAccredit(req);
        return i>0?Result.success():Result.error();
    };

    /**
     * 查询资产赋权用户信息
     * @param req 响应参数
     * @return 返回结果
     */
    @PostMapping("/findUserIdList")
    @Operation(summary = "查询资产赋权用户信息",
            description = "查询资产赋权用户信息")
    public Result findUserIdList(@RequestBody AssetAuthorization req){
        List<Long> list = assetAuthorizationService.findUserIdList(req);
        return Result.success(list);
    }

    /**
     * 查询资产赋权部门的信息
     * @param req 响应参数
     * @return 返回结果
     */
    @PostMapping("/findDeptIdList")
    @Operation(summary = "查询资产赋权部门的信息",
            description = "查询资产赋权部门的信息")
    public Result findDeptIdList(@RequestBody AssetAuthorization req){
        List<Long> list = assetAuthorizationService.findDeptIdList(req);
        return Result.success(list);
    }
}
