package com.muyu.server.mapper;

import com.baomidou.mybatisplus.core.conditions.query.LambdaQueryWrapper;
import com.muyu.common.domain.AssetAuthorization;
import com.muyu.common.domain.DataName;
import com.muyu.common.domain.TableNames;
import com.muyu.common.system.domain.SysDept;
import org.apache.ibatis.annotations.Mapper;
import org.apache.ibatis.annotations.Param;

import java.util.ArrayList;
import java.util.List;

/**
 * @Author：yang
 * @Package：com.muyu.server.mapper
 * @Project：cloud-property
 * @name：DataRunNameMapper
 * @Date：2024/8/27 20:01
 */
@Mapper
public interface DataRunNameMapper {
    void addDataRunName(@Param("list") ArrayList<DataName> list);

    void addTableRunName(@Param("tableNames1") List<TableNames> tableNames1);

    /**
     * 查询部门管理数据
     *
     * @param dept 部门信息
     *
     * @return 部门信息集合
     */
    List<SysDept> selectDeptList(SysDept dept);

    /**
     *  传入用户ID，
     * @param userId
     * @return
     */
    List<AssetAuthorization> findTableIdAndBasicIdByUserId(Long userId);

    /**
     * 传入部门ID，获取该部门下所有授权的表ID和基础ID
     * @param deptId
     * @return
     */
    List<AssetAuthorization> findTableIdAndBasicIdByDeptId(Long deptId);

    /**
     * 添加用户权限的信息
     * @param authorization 相应参数
     * @return 返回结果
     */
    Integer addUserAssetAuthorization(AssetAuthorization authorization);

    /**
     * 添加部门权限的信息
     * @param authorization 响应参数
     * @return 返回结果
     */
    Integer addDeptAssetAuthorization(AssetAuthorization authorization);

    /**
     * 查询资产赋权用户信息
     * @param req 响应参数
     * @return 返回结果
     */
    List<Long> findUserIdList(AssetAuthorization req);

    /**
     * 查询资产赋权部门的信息
     * @param req 响应参数
     * @return 返回结果
     */
    List<Long> findDeptIdList(AssetAuthorization req);

    Long delDeptAssetAccredit(@Param("deptId") Integer deptId);

    Long delUserAssetAccreditDept(@Param("userId") Integer userId);
}
