package com.muyu.server.service.impl;

import com.baomidou.mybatisplus.core.conditions.query.LambdaQueryWrapper;
import com.baomidou.mybatisplus.extension.service.impl.ServiceImpl;
import com.muyu.common.domain.CoreDataList;
import com.muyu.common.domain.ProductData;
import com.muyu.server.mapper.CoreDataListMapper;
import com.muyu.server.service.CoreDataListService;
import com.muyu.server.service.DataService;
import lombok.AllArgsConstructor;
import org.apache.commons.lang3.StringUtils;
import org.springframework.stereotype.Service;

import java.util.List;

/**
 * @Author：张腾
 * @Package：com.muyu.server.service.impl
 * @Project：cloud-integration
 * @name：DataSourceServiceImpl
 * @Date：2024/8/20 18:57
 */
@Service
@AllArgsConstructor
public class CoreDataListServiceImpl
        extends ServiceImpl<CoreDataListMapper, CoreDataList>
        implements CoreDataListService {

    private final DataService dataService;

    /**
     * 查询核心数据库
     * @param productData 客户列表请求参数
     * @return 核心数据库列表
     */
    @Override
    public List<CoreDataList> extractData(ProductData productData) {

        LambdaQueryWrapper<CoreDataList> queryWrapper = new LambdaQueryWrapper<>();
        queryWrapper.like(
                StringUtils.isNotEmpty(productData.getName()),
                CoreDataList::getName, productData.getName()
        );
        queryWrapper.like(
                StringUtils.isNotEmpty(productData.getAddress()),
                CoreDataList::getAddress, productData.getAddress()
        );
        List<CoreDataList> dataSourceListList = this.list(queryWrapper);
        return dataSourceListList.stream()
                .map(
                        coreDataList -> CoreDataList.coreDataBuild(
                                coreDataList,
                                () -> dataService.selectCoreDataListByAppCodeAndLimit(coreDataList.getIdCard(),5)
                                        .stream()
                                        .toList()
                        )
                )
                .toList();
    }

}
