package com.muyu.server.service.impl;

import com.alibaba.druid.pool.DruidDataSource;
import com.alibaba.druid.pool.DruidPooledConnection;
import com.baomidou.mybatisplus.extension.service.impl.ServiceImpl;
import com.muyu.common.core.utils.StringUtils;
import com.muyu.common.domain.*;
import com.muyu.server.mapper.DataSourceMapper;
import com.muyu.server.service.DataSourceService;
import com.muyu.server.util.JdbcHelper;
import org.springframework.stereotype.Service;

import java.sql.*;
import java.util.ArrayList;
import java.util.Date;
import java.util.List;
import java.util.concurrent.ExecutorService;
import java.util.concurrent.Executors;

/**
 * @Author：张腾
 * @Package：com.muyu.server.service.impl
 * @Project：cloud-integration
 * @name：DataSourceServiceImpl
 * @Date：2024/8/20 18:57
 */
@Service
public class DataSourceServiceImpl
        extends ServiceImpl<DataSourceMapper, ProductData>
        implements DataSourceService {

    /**
     * 抽取数据列表
     * @param connect 数据实体类
     * @return 返回试图
     */
    @Override
    public List<ProductData> extractData(Connect connect) {
        ExecutorService executorService = Executors.newFixedThreadPool(100);
        ArrayList<ProductData> productData = new ArrayList<>();
        int size = 5000;


        executorService.submit(()->{
            try {
                if (StringUtils.isEmpty(connect.getIpAddress())){
                    throw new RuntimeException("请输入ip地址+端口号! 格式:127.0.0.1:3306");
                }

                if (StringUtils.isEmpty(connect.getUserName())){
                    throw new RuntimeException("请输入数据库用户名!");
                }

                if (StringUtils.isEmpty(connect.getPassword())){
                    throw new RuntimeException("请输入数据库密码");
                }
                int count = 2;
                for (int i = 1; i < count; i++) {

                    try {

                        String sql = null;
                        DruidDataSource conn = JdbcHelper.getConn(connect);
                        String like = "";
                        String substring = like.substring(1);
                        if (StringUtils.isNotEmpty(connect.getTableName())) {
                            sql = "select " + substring + " from " + connect.getTableName() +" LIMIT "+i+","+size;
                            i=i+size;
                            count=count+size;
                            count++;
                        }
                        DruidPooledConnection connection = conn.getConnection();
                        PreparedStatement preparedStatement = connection.prepareStatement(sql);
                        ResultSet rs = preparedStatement.executeQuery();

                        while (rs.next()) {

                            int pid = 0;
                            if (substring.contains("pid")){
                                pid =  rs.getInt("pid");
                            }
                                String name = (rs.getString("COLUMN_NAME"));
                                String gender = (rs.getString("gender"));
                                Date birthday = (rs.getDate("birthday"));
                                String address = (rs.getString("address"));
                                String mibile = (rs.getString("mibile"));
                                String idCard = (rs.getString("idCard"));
                                String email = (rs.getString("email"));
                                String credit = (rs.getString("credit"));
                                String id = (rs.getString("id"));
                        ProductData productDatas = new ProductData(
                                    pid,name,gender,birthday,address,mibile,idCard,email,credit,id
                            );
                            productData.add(productDatas);
                        }
                        if (!rs.next()){
                            break;
                        }
                        JdbcHelper.close(connection, preparedStatement, rs);

                    } catch (Exception e) {
                        throw new RuntimeException(e);
                    }
                }

            } catch (Exception e) {
                e.printStackTrace();
            }
        });
        return productData;
    }

    /**
     * 抽取结构
     * @param connect 实体类
     * @return 返回试图
     */
    @Override
    public List<TableFie> extractTableField(Connect connect) {


        if (StringUtils.isEmpty(connect.getIpAddress())){
            throw new RuntimeException("请输入ip地址+端口号! 格式:127.0.0.1:3306");
        }

        if (StringUtils.isEmpty(connect.getUserName())){
            throw new RuntimeException("请输入数据库用户名!");
        }

        if (StringUtils.isEmpty(connect.getPassword())){
            throw new RuntimeException("请输入数据库密码");
        }

                String sql = null;
                DruidDataSource druidDataSource = JdbcHelper.getConn(connect);
                if (StringUtils.isNotEmpty(connect.getTableName())) {
                    sql = "SHOW FULL FIELDS FROM " + connect.getTableName();
                }
        try (Connection conn = druidDataSource.getConnection()) {
            // 在这里执行你的数据库操作
            PreparedStatement preparedStatement = conn.prepareStatement(sql);
            ResultSet rs = preparedStatement.executeQuery();
            ArrayList<TableFie> tableFIES = new ArrayList<>();
            while (rs.next()) {
                // 使用正确的列名 Field

                TableFie tableFie = TableFie.builder()
                        // 假设你修改了字段名为 fieldId，以符合常规命名规范
                        .field(rs.getString("Field"))
                        .type(rs.getString("Type"))
                        .collation(rs.getString("Collation"))
                        // 转换为布尔值，假设你想要这个字段
                        .nullable(rs.getString("Null"))
                        .primarys(rs.getString("Key"))
                        .annotation(rs.getString("Comment"))
                        .build();
                tableFIES.add(tableFie);
            }
            JdbcHelper.close(conn,preparedStatement,rs);
            return tableFIES;
        } catch (SQLException e) {
            e.printStackTrace();
        }

        return null;

    }


}
